@@ -243,10 +243,13 @@ var Sidebar = GObject.registerClass({
             loadMoreRow.showNoMore();
         });
 
+        this._query.connect('run', () => {
+            this._instructionStack.visible_child = this._instructionSpinner;
+        });
+
         this._query.connect('notify', () => {
-            if (this._query.isValid()) {
-                this._instructionStack.visible_child = this._instructionSpinner;
-            } else if (this._instructionStack.visible_child !== this._errorLabel) {
+            if (this._instructionStack.visible_child !== this._instructionSpinner &&
+                this._instructionStack.visible_child !== this._errorLabel) {
                 if (this._query.transportation === RouteQuery.Transportation.TRANSIT) {
                     this._clearTransitOverview();
                     this._showTransitOverview();
